@@ -232,7 +232,7 @@ gchar *get_upper_snake_from_lower_snake(const gchar *lowerSnake)
     g_return_val_if_fail(lowerSnake != NULL && *lowerSnake != '\0', NULL);
 
     ret = g_new(gchar, BUFFER_SIZE);
-    ret[0] = '\0';
+    memset(ret, 0, BUFFER_SIZE);
 
     for (i = 0; i < (guint)strlen(lowerSnake); i++) {
         if (lowerSnake[i] == '_') {
@@ -905,6 +905,8 @@ void generate_code_from_template(FILE *in, FILE *out, Structure *structure, GHas
                     generate_source_includes(out, structure);
                 } else if (g_strcmp0(buffer, "header_declaration") == 0) {
                     generate_header_header_declaration(out, structure);
+                } else if (g_strcmp0(buffer, "body_declaration") == 0) {
+                    generate_source_body_declaration(out, structure);
                 } else if (g_hash_table_contains(table, buffer)) {
                     val = g_hash_table_lookup(table, buffer);
                     write_str(out, val);
@@ -1585,11 +1587,29 @@ gchar *get_translator_for_return(Ret *ret)
     return res;
 }
 
+static gboolean annotation_contains_nullable(GList *annotations) /* gchar * */
+{
+    GList *link;
+
+    for (link = annotations; link; link = g_list_next(link)) {
+        if (g_strcmp0(link->data, "allow-none") == 0 ||
+            g_strcmp0(link->data, "nullable") == 0) {
+              break;
+        }
+    }
+
+    return link != NULL;
+}
+
 gchar *get_inline_parameter(Parameter *para)
 {
     gchar *buffer;
     gchar *ret;
     gchar *translator;
+    gboolean is_nullable;
+
+    is_nullable = !para->translator && !is_enum_type(para->type) &&
+                  annotation_contains_nullable(para->annotations);
 
     buffer = g_new(gchar, BUFFER_SIZE);
     *buffer = '\0';
@@ -1603,6 +1623,11 @@ gchar *get_inline_parameter(Parameter *para)
     }
 
     if (translator != NULL) {
+        if (is_nullable) {
+            (void)g_stpcpy(buffer + strlen(buffer), "((");
+            (void)g_stpcpy(buffer + strlen(buffer), para->name);
+            (void)g_stpcpy(buffer + strlen(buffer), ")?(");
+        }
         (void)g_stpcpy(buffer + strlen(buffer), translator);
         (void)g_stpcpy(buffer + strlen(buffer), " (");
         if (para->translator == NULL && !is_enum_type(para->type))
@@ -1616,31 +1641,11 @@ gchar *get_inline_parameter(Parameter *para)
             (void)g_stpcpy(buffer + strlen(buffer), ")");
         }
         (void)g_stpcpy(buffer + strlen(buffer), ")");
+        if (is_nullable) {
+            (void)g_stpcpy(buffer + strlen(buffer), "):NULL)");
+        }
     }
 
-    /*
-       if (translator != NULL) {
-       if (para->translatorArgus != NULL) {
-       for (iter = g_list_first (para->translatorArgus); iter != NULL; iter = g_list_next (iter)) {
-       (void)g_stpcpy (buffer + strlen (buffer), ", ");
-       (void)g_stpcpy (buffer + strlen (buffer), (gchar *)iter->data);
-       }
-       }
-
-       else if (para->translator == NULL) {
-       trueType = get_true_type (para->type);
-       if (g_hash_table_contains (type2structure, trueType)) {
-       structure = g_hash_table_lookup (type2structure, trueType);
-       if (structure->isBare == FALSE) {
-       (void)g_stpcpy (buffer + strlen (buffer), ", NULL");
-       }
-       }
-       g_free (trueType);
-       }
-       (void)g_stpcpy (buffer + strlen (buffer), ")");
-       g_free (translator);
-       }
-     */
     ret = g_new(gchar, strlen(buffer) + 1);
     (void)g_stpcpy(ret, buffer);
     g_free(buffer);
@@ -2032,7 +2037,6 @@ void generate_header_enum(FILE *out, Enumeration *enumeration)
 gchar *get_source_run_time_checkers(Method *method, const gchar *namespace)
 {
     GList *iter;
-    GList *jter;
     Parameter *parameter;
     guint i;
     gchar *buffer;
@@ -2064,6 +2068,11 @@ gchar *get_source_run_time_checkers(Method *method, const gchar *namespace)
 
             if (i == namespace_len) {
                 (void)g_stpcpy(buffer + strlen(buffer), "\t");
+                if (annotation_contains_nullable(parameter->annotations)) {
+                    (void)g_stpcpy(buffer + strlen(buffer), "if(");
+                    (void)g_stpcpy(buffer + strlen(buffer), parameter->name);
+                    (void)g_stpcpy(buffer + strlen(buffer), ")\n\t\t");
+                }
                 nameSpaceUpperSnake = get_upper_snake_from_upper_camel(namespace);
                 nameUpperSnake = get_upper_snake_from_upper_camel(trueType + i);
                 typeCheck =
@@ -2101,14 +2110,7 @@ gchar *get_source_run_time_checkers(Method *method, const gchar *namespace)
                 (void)g_stpcpy(buffer + strlen(buffer), "\n");
             }
 
-            for (jter = g_list_first(parameter->annotations); jter != NULL;
-                 jter = g_list_next(jter)) {
-                if (g_strcmp0((gchar *)jter->data, "allow-none") == 0) {
-                    break;
-                }
-            }
-
-            if (jter == NULL) {
+            if (i != namespace_len && !annotation_contains_nullable(parameter->annotations)) {
                 (void)g_stpcpy(buffer + strlen(buffer), "\t");
                 if (method->ret != NULL) {
                     (void)g_stpcpy(buffer + strlen(buffer), "g_return_val_if_fail (");
@@ -2301,7 +2303,7 @@ static gint generate_library(const gchar *apis_dir)
     return res;
 }
 
-void generate_header_header_declaration(FILE *out, Structure *structure)
+static void generate_declarations(FILE *out, Structure *structure, const gchar *position)
 {
     GList *list_iter;
     Declaration *declaration;
@@ -2312,7 +2314,7 @@ void generate_header_header_declaration(FILE *out, Structure *structure)
          list_iter = g_list_next(list_iter)) {
         declaration = (Declaration *)list_iter->data;
 
-        if (g_strcmp0(declaration->position, "header") == 0) {
+        if (g_strcmp0(declaration->position, position) == 0) {
             write_str(out, declaration->content);
             write_str(out, "\n");
         }
@@ -2320,6 +2322,16 @@ void generate_header_header_declaration(FILE *out, Structure *structure)
     }
 }
 
+void generate_header_header_declaration(FILE *out, Structure *structure)
+{
+    generate_declarations(out, structure, "header");
+}
+
+void generate_source_body_declaration(FILE *out, Structure *structure)
+{
+    generate_declarations(out, structure, "body");
+}
+
 void generate_header_header_file(GList *structures)
 {
     FILE *out;
