@@ -153,8 +153,8 @@
 
 extern struct icalgauge_impl *icalss_yy_gauge;
 
-#define YYPARSE_PARAM yy_globals
-#define YYLEX_PARAM yy_globals
+//#define YYPARSE_PARAM yy_globals
+//#define YYLEX_PARAM yy_globals
 #define YY_EXTRA_TYPE  icalgauge_impl*
 
 
@@ -881,7 +881,7 @@ int yydebug;
 # define YYMAXDEPTH 10000
 #endif
 
-
+
 
 #if YYERROR_VERBOSE
 
@@ -1092,7 +1092,7 @@ yysyntax_error (char *yyresult, int yystate, int yychar)
     }
 }
 #endif /* YYERROR_VERBOSE */
-
+
 
 /*-----------------------------------------------.
 | Release the memory associated to this symbol.  |
@@ -1124,7 +1124,7 @@ yydestruct (yymsg, yytype, yyvaluep)
         break;
     }
 }
-
+
 
 /* Prevent warnings from -Wmissing-prototypes.  */
 
